package Alien::OpenSSL::Static;

use parent 'Alien::Base';
our $VERSION = '1.000001';

=head1 NAME

Alien::OpenSSL::Static - Alien wrapper for OpenSSL

=head1 ABSTRACT

Alien wrapper for OpenSSL

=cut

1;
